@@ -86,8 +86,10 @@ get_station_weather_data(const gchar *station_id_with_path, GHashTable *data,
         if(!doc)
             return -1;
         root_node = xmlDocGetRootElement(doc);
-        if (!root_node)
+        if (!root_node){
+            xmlFreeDoc(doc);
             return -1;
+        }
         /*  htmlDocDump(stdout, doc); */
         if(root_node->type == XML_ELEMENT_NODE &&
                 strstr((char*)root_node->name, "err")){
@@ -670,29 +672,31 @@ fill_current_data(xmlNode *root_node, GHashTable *current_weather, GHashTable *d
 
                                                 xmlFree(temp_xml_string);
                                                 temp_xml_string = xmlNodeGetContent(child_node11);
-                                                strptime((char*)temp_xml_string,"%H:%M", &tmp_tm);
-                                                setlocale(LC_TIME, "POSIX");
-                                                strftime(temp_buffer, sizeof(temp_buffer) - 1, "%I:%M %p", &tmp_tm);
-                                                setlocale(LC_TIME, "");
+                                                if (temp_xml_string){
+                                                    strptime((char*)temp_xml_string,"%H:%M", &tmp_tm);
+                                                    setlocale(LC_TIME, "POSIX");
+                                                    strftime(temp_buffer, sizeof(temp_buffer) - 1, "%I:%M %p", &tmp_tm);
+                                                    setlocale(LC_TIME, "");
 
-                                                tmp_list = g_hash_table_lookup(data, "forecast");
-                                                while(tmp_list ){
-                                                    tmp_hash = (GHashTable*)tmp_list->data;
-                                                    if (g_hash_table_lookup(tmp_hash,"day_date")&&
-                                                        strcmp(current_day,g_hash_table_lookup(tmp_hash,"day_date"))){
-                                                        g_hash_table_insert(tmp_hash, "day_sunset_not_realistically", g_strdup(buffer));
-                                                        g_hash_table_insert(tmp_hash, "day_sunrise_not_realistically", g_strdup(temp_buffer));
-                                                    }else{
-                                                        g_hash_table_insert(tmp_hash, "day_sunset", g_strdup(temp_buffer));
-                                                        g_hash_table_insert(tmp_hash, "day_sunrise", g_strdup(buffer));
-                                                        /*
-                                                         fprintf(stderr, "Real Sunrise %s\n", buffer); 
-                                                         fprintf(stderr, "Real Sunset %s\n", temp_buffer); 
-                                                        */
-                                                        
+                                                    tmp_list = g_hash_table_lookup(data, "forecast");
+                                                    while(tmp_list ){
+                                                        tmp_hash = (GHashTable*)tmp_list->data;
+                                                        if (g_hash_table_lookup(tmp_hash,"day_date")&&
+                                                            strcmp(current_day,g_hash_table_lookup(tmp_hash,"day_date"))){
+                                                            g_hash_table_insert(tmp_hash, "day_sunset_not_realistically", g_strdup(buffer));
+                                                            g_hash_table_insert(tmp_hash, "day_sunrise_not_realistically", g_strdup(temp_buffer));
+                                                        }else{
+                                                            g_hash_table_insert(tmp_hash, "day_sunset", g_strdup(temp_buffer));
+                                                            g_hash_table_insert(tmp_hash, "day_sunrise", g_strdup(buffer));
+                                                            /*
+                                                             fprintf(stderr, "Real Sunrise %s\n", buffer); 
+                                                             fprintf(stderr, "Real Sunset %s\n", temp_buffer); 
+                                                            */
+                                                            
+                                                        }
+
+                                                        tmp_list = g_slist_next(tmp_list);
                                                     }
-
-                                                    tmp_list = g_slist_next(tmp_list);
                                                 }
 
                                                 if (child_node9)
@@ -714,9 +718,13 @@ fill_current_data(xmlNode *root_node, GHashTable *current_weather, GHashTable *d
                                                     if (!strncmp(temp_xml_string,"moon4",5))
                                                         g_hash_table_insert(current_weather, "moon_phase", 
                                                                                             g_strdup("First Quarter"));
-                                                    if (!strncmp(temp_xml_string,"moon5",5))
+                                                    if (!strncmp(temp_xml_string,"moon6",5))
                                                         g_hash_table_insert(current_weather, "moon_phase", 
                                                                                             g_strdup("Waxing Gibbous"));
+                                                    if (!strncmp(temp_xml_string,"moon8",5))
+                                                        g_hash_table_insert(current_weather, "moon_phase", 
+                                                                                            g_strdup("Full"));
+ 
                                                     xmlFree(temp_xml_string);
                                                 }
 /*
